<?php
namespace Zeedhi\DataMining\Common\Util;

use Zeedhi\Framework\DB\Mongo\Mongo as MongoConnection;
use Zeedhi\DataMining\Common\Service\ConnectionFactory;
use Zeedhi\DataMining\Common\Service\Connection;

class Environment {

    protected $mongoHost;

    protected $mongoPort;

    protected $dbNamePrefix;

    protected $zmartConnection;

    protected $organization;

    protected $organizationConnection;

    protected $organizationConnectionParams;

    protected $connectionService;


    public function __construct(MongoConnection $zmartConnection, $mongoHost, $mongoPort, $dbNamePrefix) {
        $this->mongoHost = $mongoHost;
        $this->mongoPort = $mongoPort;
        $this->dbNamePrefix = $dbNamePrefix;
        $this->zmartConnection = $zmartConnection;
        $this->organizationConnectionParams = array();
    }

    public function setConnectionService(Connection $connectionService) {
        $this->connectionService = $connectionService;
    }

    public function setOrganization($organization) {
        if (!empty($organization) && $organization != $this->organization) {
            $this->organization = $organization;
            $this->factoryOrganizationConnection();
        }
    }

    public function getOrganization() {
        return $this->organization;
    }

    public function getMongoHost() {
        return $this->mongoHost;
    }

    public function getMongoPort() {
        return $this->mongoPort;
    }

    public function getDbNamePrefix() {
        return $this->dbNamePrefix;
    }

    public function getZmartConnection() {
        return $this->zmartConnection;
    }

    protected function factoryOrganizationConnection() {
        $connectionParams = $this->connectionService->findByOrganization($this->getOrganization());
        $this->setOrganizationConnectionParams($connectionParams);
        $this->organizationConnection = ConnectionFactory::createMongoConnection($this->getOrganization(), $this->getMongoHost(), $this->getMongoPort(), $this->getDbNamePrefix(), $this->getOrganizationConnectionParams());
    }

    /**
     * @return MongoConnection
     *
     * @throws \Exception
     */
    public function getOrganizationConnection() {
        if (!is_null($this->organizationConnection)) {
            return $this->organizationConnection;
        }
        throw new \Exception("Connection not configured. Provide the organization id.");
    }

    protected function setOrganizationConnectionParams($connectionParams) {
        $this->organizationConnectionParams = array(
            'username' => $connectionParams['username'],
            'password' => $connectionParams['password']
        );
    }

    public function getOrganizationConnectionParams() {
        return $this->organizationConnectionParams;
    }

}